#!/bin/bash
PACKAGE_NAME="window-manager-ccl32"
PACKAGE_VERSION="1.0.0"
DATA_ARCHIVE="data.tar.gz"
TARGET_TYPE="amd64"
STARTUP_SCRIPT=""

echo "Installing ${PACKAGE_NAME} v${PACKAGE_VERSION}"

# Check if prefix have been set
if [ -z "$1" ]; then
  PREFIX="/"
else
  PREFIX=$1
fi

# Check if enable have been set
if [ -z "$2" ]; then
	ENABLE=true
else
  	ENABLE=$2
fi

echo "Extracting ${DATA_ARCHIVE} to ${PREFIX}"
tar -xof ${DATA_ARCHIVE} -C ${PREFIX}

# Check if extraction was successful
if [ $? -ne 0 ]; then
	echo "Installation failed: Failed to extract files from archive ${DATA_ARCHIVE}";
	exit 1
else
	echo "Installation success: Files from archive ${DATA_ARCHIVE} extracted successfully";
fi

# Determine how the application should auto-start. Only performed if extracted on default location.
if [ "$PREFIX" == "/" ] ; then
	if [ "$TARGET_TYPE" == "tg" ] || [ "$TARGET_TYPE" == "imx8" ]; then
		if $ENABLE ; then
			echo "Enable systemd service..."
			# clean ccl from service name as made earlier
			systemctl enable ${PACKAGE_NAME//-ccl[0-9][0-9]/}
		else
			echo "Disable systemd service..."
			# clean ccl from service name as made earlier
			systemctl disable ${PACKAGE_NAME//-ccl[0-9][0-9]/}
		fi

		if [ $? -ne 0 ]; then
			echo "Installation failed: Failed to enable/disable systemd service. See previous error.";
			exit 1
		else
			echo "Success: Service enabled/disabled successfully";
		fi
	else
		if $ENABLE ; then
			echo "Enable startup script..."
			chmod +x /opt/etc/init.d/${STARTUP_SCRIPT}
		else
			echo "Disable startup script..."
			chmod -x /opt/etc/init.d/${STARTUP_SCRIPT}
		fi

		if [ $? -ne 0 ]; then
			echo "Installation failed: Failed to set script execute permission. See previous error.";
			exit 1
		else
			echo "Success: Application execute permission set successfully";
		fi
	fi
else
	echo "Setup of application startup omitted. Only performed when extracted to default location."
fi

# Update library cache
if [ "$TARGET_TYPE" == "imx5" ] || [ "$TARGET_TYPE" == "imx6" ] || [ "$TARGET_TYPE" == "corei7" ]; then
    ldconfig -C /opt/etc/ld.so.cache
elif [ "$TARGET_TYPE" == "imx8" ]; then
    ldconfig
fi

# Create package stamp to indicate successful installation
if [ ! -d "/opt/packages" ]; then
	mkdir -p /opt/packages
fi
touch /opt/packages/${PACKAGE_NAME}_${PACKAGE_VERSION}_${TARGET_TYPE}
echo "Package stamp created under /opt/packages";

exit 0
